@@ -1,7 +1,6 @@
 use super::{CharacterSetFields, InformationSchema, SchemaQueryBuilder};
 use crate::sqlx_types::{mysql::MySqlRow, Row};
-use sea_query::{Expr, Iden, Order, Query, SelectStatement};
-use std::rc::Rc;
+use sea_query::{Expr, Iden, Order, Query, SeaRc, SelectStatement};
 
 #[derive(Debug, sea_query::Iden)]
 /// Ref: https://dev.mysql.com/doc/refman/8.0/en/information-schema-tables-table.html
@@ -50,7 +49,7 @@ pub struct TableQueryResult {
 }
 
 impl SchemaQueryBuilder {
-    pub fn query_tables(&self, schema: Rc<dyn Iden>) -> SelectStatement {
+    pub fn query_tables(&self, schema: SeaRc<dyn Iden>) -> SelectStatement {
         type Schema = InformationSchema;
         Query::select()
             .columns(vec![
